@@ -1,5 +1,6 @@
 from abc import ABCMeta, abstractmethod
 from collections.abc import AsyncGenerator, Awaitable, Coroutine
+from enum import Enum
 from typing import Any, Callable, Generic, Optional, Union, overload, runtime_checkable
 
 from PIL import Image
@@ -1237,11 +1238,23 @@ class AudioDetectionPluginResponse(TypedDict):
     detected: bool
 
 
+class CuiCapability(str, Enum):
+    MotionDetector = "MotionDetector"
+    ObjectDetector = "ObjectDetector"
+    AudioDetector = "AudioDetector"
+    PTZMove = "PTZMove"
+    PTZHome = "PTZHome"
+    PTZPresets = "PTZPresets"
+    PTZZoom = "PTZZoom"
+
+
 class BasePlugin(metaclass=ABCMeta):
     @abstractmethod
     def __init__(self, logger: "LoggerService", api: "PluginAPI") -> None: ...
     @abstractmethod
     async def configureCameras(self, cameras: list[CameraDevice]) -> None: ...
+    @abstractmethod
+    async def getCapabilities(self) -> list[CuiCapability]: ...
 
 
 class MotionDetectionPlugin(BasePlugin):
@@ -1271,9 +1284,14 @@ class AudioDetectionPlugin(BasePlugin):
     ) -> AudioDetectionPluginResponse: ...
 
 
+class PtzPlugin(BasePlugin):
+    pass
+
+
 @runtime_checkable
 class PluginInterface(Protocol):
     async def configureCameras(self, camera_devices: list[CameraDevice]) -> None: ...
+    async def getCapabilities(self) -> list[CuiCapability]: ...
     async def interfaceSchema(self) -> Optional[list[JsonSchema]]: ...
     async def detectMotion(
         self, video_data: bytes, config: dict[str, Any]
